@@ -18,6 +18,7 @@ import os
 import array
 import re
 import time
+import urlparse
 
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
@@ -72,18 +73,30 @@ class fMMS_controller():
 		return color_style.lookup_color(logicalcolorname)
 	
 	
+	def get_host_from_url(self, url):
+		if not url.startswith("http://"):
+			url = "http://%s" % url
+
+		ret = urlparse.urlparse(url)
+		ret = ret[1].split(":")[0]
+		
+		return ret
+	
+	
 	def convert_timeformat(self, intime, format, hideToday=False):
 		mtime = intime
 		try:
 			mtime = time.strptime(mtime)
 		except ValueError, e:
-			log.info("timeconversion stage1 failed: %s %s", type(e), e)
+			#log.info("timeconversion stage1 failed: %s %s", type(e), e)
 			try:
 				mtime = time.strptime(mtime, "%Y-%m-%d %H:%M:%S")
 			except ValueError, e:
-				log.info("timeconversion stage2 failed: %s %s", type(e), e)
+				#log.info("timeconversion stage2 failed: %s %s", type(e), e)
+				pass
 		except Exception, e:
-			log.exception("Could not convert timestamp: %s %s", type(e), e)
+			#log.exception("Could not convert timestamp: %s %s", type(e), e)
+			pass
 		
 		# TODO: check if hideToday == true
 		# TODO: remove date if date == today
